searching module
================

.. automodule:: whoosh.searching

Classes
-------

.. autoclass:: Searcher
    :inherited-members:
    :members:

.. autoclass:: Results
    :members:
    
.. autoclass:: Paginator
    :members:
